title:      Callouts
desc:       Docnado Markdown Quick Reference
date:       2018/10/12
version:    1.0.0
template:   document
nav:        Document __2__>Callouts
percent:    100
authors:    enq@heinventions.com

Often when writing documentation you want to draw your audience's attention in some way, perhaps to a safety warning or operational tip. Docnado does this with our callout tags!

Simply follow a line with a tag describing which style of callout you want to use.

```markdown
Callouts are designed to draw attention to a particular class of information. This is a long information callout with **bold** text and *italic* text too. It is designed to span multiple lines so that you can see how the paragraph will break across the info callout.
{: .info}

Warning style callouts can be added too. Keep them punchy.
{: .warning}

Dangerous warnings go here.
{: .danger}

Take a look at the Markdown file to see how these are implemented.
{: .tip}
```

Callouts are designed to draw attention to a particular class of information. This is a long information callout with **bold** text and *italic* text too. It is designed to span multiple lines so that you can see how the paragraph will break across the info callout.
{: .info}

Warning style callouts can be added too. Keep them punchy.
{: .warning}

Dangerous warnings go here.
{: .danger}

Take a look at the Markdown file to see how these are implemented.
{: .tip}
